package com.ruoyi.oa.mapper;

import java.util.List;
import com.ruoyi.oa.domain.CmcStudy;

/**
 * 学习记录Mapper接口
 * 
 * @author cmc
 * @date 2025-03-06
 */
public interface CmcStudyMapper 
{
    /**
     * 查询学习记录
     * 
     * @param studyId 学习记录主键
     * @return 学习记录
     */
    public CmcStudy selectCmcStudyByStudyId(Integer studyId);

    /**
     * 查询学习记录列表
     * 
     * @param cmcStudy 学习记录
     * @return 学习记录集合
     */
    public List<CmcStudy> selectCmcStudyList(CmcStudy cmcStudy);

    /**
     * 查询学习记录统计
     *
     * @param cmcStudy 学习记录
     * @return 学习记录集合
     */
    public List<CmcStudy> selectCmcStudyStatistic(CmcStudy cmcStudy);

    /**
     * 新增学习记录
     * 
     * @param cmcStudy 学习记录
     * @return 结果
     */
    public int insertCmcStudy(CmcStudy cmcStudy);

    /**
     * 修改学习记录
     * 
     * @param cmcStudy 学习记录
     * @return 结果
     */
    public int updateCmcStudy(CmcStudy cmcStudy);

    /**
     * 删除学习记录
     * 
     * @param studyId 学习记录主键
     * @return 结果
     */
    public int deleteCmcStudyByStudyId(Integer studyId);

    /**
     * 批量删除学习记录
     * 
     * @param studyIds 需要删除的数据主键集合
     * @return 结果
     */
    public int deleteCmcStudyByStudyIds(Integer[] studyIds);
}
